@@ -19,4 +19,6 @@
 
 #include "sessionuiproxy.h"
 
-KSmtp::SessionUiProxy::~SessionUiProxy() {}
+KSmtp::SessionUiProxy::~SessionUiProxy()
+{
+}
